// Citire temperatură, umiditate și viteză ventilator pe telefon flosind Bluetooth HC05

// Componente hardware necesare:
// 1. Arduino MEGA 2560 board circuit
// 2. Bluetooth HC05
// 3. Senzor de temperatură și umiditate tip DHT11
// 4. Ventilator 5V DC
// 5. Rezistor 1K montat în baza tranzistorului 1N2222
// 6. Tranzistor comutație 1N2222 pentru comanda ventilatorului
// 7. Diodă 1N4007 montată în paralel la bornele ventilatorului
// 8. Placă de încercări bread board
// 9. Conectori cu pini
// 10. Sursă de tensiune (baterie 9V sau alimentator 12V DC)

// Componente software necesare:
// 1. Arduino IDE - creare și transfer program în Arduino 2560
// 2. Softul de creare a aplicației de afișare a datelor pe telefon - MIT App Inventor


#include <SoftwareSerial.h>             //include librăria SoftwareSerial care operează cu bluetooth HC05
#include <DHT.h>                        //include librăria DHT care operează cu senzorul DTH11 (DHT sensor library by Adafruit)
#define DATAPIN 2                       //definește pinul 2 ca pin de date pentru senzorul DHT11
#define DHTTYPE DHT11                   //definește tipul de senzor
const byte rxPin = 10;                  //pinul 10 este RX (recepţie date de la telefon la Arduino)
const byte txPin = 9;                   //pinul 9 este TX (transmisie date de la Arduino la telefon)
SoftwareSerial btSerial(rxPin, txPin);  //btSerial este numele atribuit dispozitivului bluetooth conectat la pinii 10,9 ai Arduino 2560


DHT dht(DATAPIN, DHTTYPE);  //setează datele necesare pentru librăria DHT care operează cu senzorul: nume = dht(pin de date, tip de senzor)
int temp;                   //variabila care stochează valorile de temperatură
int umid;                   //variabila care stochează valorile de umiditate
int ventPin = 5;            //atribuie pinul 5 al plăcuţei Arduino 2560 pentru ventilator
byte ventVitAut;               //setează variabila care stochează viteza ventilatorului (valori între 0 = minim = oprit şi 255 = maxim)
int vent;                   //variabila care stochează valoarea vitezei în procente
String comanda;
byte ventVitMan;                 //variabila care stochează modul de lucru

void setup() 
{
  pinMode(rxPin, INPUT);       //setează pinul rxPin (10) ca intrare de date în Arduino
  pinMode(txPin, OUTPUT);      //setează pinul txPin (9) ca ieşire de date din Arduino
  pinMode(ventPin, OUTPUT);    //setează pinul 5 ca pin de ieşire pentru comanda ventilatorului
  digitalWrite(ventPin, LOW);  //setează pinul 5 pe nivel LOW = 0V
  Serial.begin(9600);          //porneşte conexiunea serială USB calculator
  btSerial.begin(9600);        //porneşte bluetooth-ul
  dht.begin();                 //porneşte senzorul DHT11
  Serial.println("Pregătit");  //afişează Pregătit pe Monitorul Serial
}

void loop() 
{
  umid = dht.readHumidity();     //citeşte umiditatea de la senzorul DHT11
  temp = dht.readTemperature();  //citeşte temperatura de la senzorul DHT11

  if (btSerial.available()) 
  {
    comanda = btSerial.read();  //citeşte comanda M = manual A = Automat
    //switch (mod)
    if(comanda == 'Automat') 
    {
      //case 'A':  //modul automat

        if (temp == 0)  //dacă temperatura este 0°C (se scoate senzorul din bread board)
        {
          ventVitAut = 0;  //setează viteza ventilatorului la 0%
        }

        if (temp <= 25)  //dacă temperatura este egală sau sub 25°C
        {
          ventVitAut = 65;  //setează viteza ventilatorului la 25%
        }

        if (temp > 25 && temp <= 32)  //dacă temperatura este > 25°C dar < 32°C
        {
          ventVitAut = 128;  //setează viteza ventilatorului la 50%
        }

        if (temp > 32)  //dacă temperatura este peste 30°C
        {
          ventVitAut = 255;  //setează viteza maximă a ventilatorului
        }
        
        Serial.print("  Aut ventilator: ");
        Serial.print(ventVitAut);  //scrie valoare pe conexiunea serială
        Serial.println();

        vent = ventVitAut * 100 / 255;  //transformă viteza în procente pentru a fi transmisă telefonului
        btSerial.print(temp);        //trimite informaţia la telefon prin bluetooth
        btSerial.print(";");         //separatorul dintre informaţii este caracterul ;
        btSerial.print(umid);        //trimite informaţia la telefon prin bluetooth
        btSerial.print(";");         //separatorul dintre informaţii este caracterul ;
        btSerial.print(vent);        //trimite informaţia la telefon prin bluetooth
        //btSerial.print(";");         //separatorul dintre informaţii este caracterul ;

        analogWrite(ventPin, ventVitAut);  //trimite la pinul 5 atribuit valoarea vitezei ventilatorului în modul manual (valoarea trimisă de telefon)
      //break;
    }

      //case 'M':  //mod manual
    else if(comanda == 'Manual') 
    {
        ventVitMan = btSerial.read();  //citește valoarea trimisă de telefon prin bluetooth
        delay(50);  //întîrziere 50ms pentru a avea tip să se citească valoarea
        Serial.print("  Man ventilator: ");
        Serial.print(ventVitMan);  //scrie valoare pe conexiunea serială
        Serial.println();
      
        btSerial.print(temp);        //trimite informaţia la telefon prin bluetooth
        btSerial.print(";");         //separatorul dintre informaţii este caracterul ;
        btSerial.print(umid);        //trimite informaţia la telefon prin bluetooth
        btSerial.print(";");         //separatorul dintre informaţii este caracterul ;
      
        analogWrite(ventPin, ventVitMan);  //trimite la pinul 5 atribuit valoarea vitezei ventilatorului în modul manual (valoarea trimisă de telefon)
       //break;
    }

        //analogWrite(ventPin, ventVit);  //trimite la pinul 5 atribuit valoarea vitezei ventilatorului în modul manual (valoarea trimisă de telefon)
  }



    // vent = ventVitAut * 100 / 255;  //transformă viteza în procente pentru a fi transmisă telefonului
    // btSerial.print(temp);        //trimite informaţia la telefon prin bluetooth
    // btSerial.print(";");         //separatorul dintre informaţii este caracterul ;
    // btSerial.print(umid);        //trimite informaţia la telefon prin bluetooth
    // btSerial.print(";");         //separatorul dintre informaţii este caracterul ;
    // btSerial.print(vent);        //trimite informaţia la telefon prin bluetooth
    // btSerial.print(";");         //separatorul dintre informaţii este caracterul ;

   
    // analogWrite(ventPin, ventVit);  //trimite la pinul 5 atribuit valoarea vitezei ventilatorului în modul manual (valoarea trimisă de telefon)
    // delay(50);
    delay(1000);  //pauză de o secundă între citiri
}

